@@ -22,7 +22,18 @@
 File containing the configuration options for the server
 '''
 
-winlist  = '/Users/users/derek/progs/tetrinet/20061124/winlist.data'
+winlist  = 'winlist.data'
+users = 'user.data'
 channel1 = '#coma'
-loglevel = 'Info'
-version = 'PyTrinet version 0.1'
+loglevel = 'INFO'
+version = 'PyTrinet version 0.2.1'
+logfile = 'pytrinet.log'
+motd = ['',
+	   '********* Message of the Day ********',
+	   'Welcome to the PyTrinet Server version %s!' %(version) ,
+	   'This server is written in python by Derek, aka shoe.',
+	   'For help, type /help',
+	   'to see a listing of the channels available, type /list',
+	   'contact info: irc://oudemans/#pytrinet', 
+	   '']
+	   
